summaryrefslogtreecommitdiff
path: root/plugins/housekeeping/gsd-ldsm-trash-empty.h
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/housekeeping/gsd-ldsm-trash-empty.h')
-rw-r--r--plugins/housekeeping/gsd-ldsm-trash-empty.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/plugins/housekeeping/gsd-ldsm-trash-empty.h b/plugins/housekeeping/gsd-ldsm-trash-empty.h
index 4d46a5b..85b09c0 100644
--- a/plugins/housekeeping/gsd-ldsm-trash-empty.h
+++ b/plugins/housekeeping/gsd-ldsm-trash-empty.h
@@ -1,14 +1,14 @@
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
*
- * gsd-ldsm-trash-empty.h
+ * msd-ldsm-trash-empty.h
* Copyright (C) Chris Coulson 2009 <[email protected]>
*
* gsd-ldsm-trash-empty.h is free software: you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by the
* Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* gsd-ldsm-trash-empty.h is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU General Public License for more details.
@@ -17,11 +17,11 @@
* with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef _gsd_ldsm_trash_empty_h_
-#define _gsd_ldsm_trash_empty_h_
+#ifndef _msd_ldsm_trash_empty_h_
+#define _msd_ldsm_trash_empty_h_
#include <gtk/gtk.h>
-void gsd_ldsm_trash_empty ();
+void msd_ldsm_trash_empty ();
-#endif /* _gsd_ldsm_trash_empty_h_ */
+#endif /* _msd_ldsm_trash_empty_h_ */
@@ -1,14 +1,14 @@
* Copyright (C) Chris Coulson 2009 <[email protected]>
*
- * gsd-ldsm-trash-empty.h is free software: you can redistribute it and/or modify it
+ * msd-ldsm-trash-empty.h is free software: you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by the
* Free Software Foundation, either version 3 of the License, or
@@ -1,14 +1,14 @@
* (at your option) any later version.
*
- * gsd-ldsm-trash-empty.h is distributed in the hope that it will be useful, but
+ * msd-ldsm-trash-empty.h is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.